#
# spec file for package python-ufoLib2
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-ufoLib2
Version:        0.17.1
Release:        2.1
Summary:        UFO font processing library
License:        Apache-2.0
URL:            https://github.com/fonttools/ufoLib2
Source:         https://files.pythonhosted.org/packages/source/u/ufolib2/ufolib2-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools_scm}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
# SECTION install_requires
BuildRequires:  %{python_module FontTools >= 4.0.0}
BuildRequires:  %{python_module attrs >= 20.1.0}
# via fonttools[ufo]
BuildRequires:  %{python_module fs >= 2.2.0}
BuildRequires:  %{python_module typing_extensions if %python-base < 3.8}
Requires:       python-FontTools >= 4.0.0
Requires:       python-attrs >= 19.2.0
Requires:       python-fs >= 2.2.0
%if 0%{?python_version_nodots} < 38
Requires:       python-typing_extensions
%endif
# /SECTION
# SECTION test requirements
BuildRequires:  %{python_module lxml}
BuildRequires:  %{python_module pytest}
# /SECTION
Suggests:       python-lxml
BuildArch:      noarch
%python_subpackages

%description
ufoLib2 is a UFO font processing library.

%prep
%setup -q -n ufolib2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/ufoLib2
%{python_sitelib}/ufolib2-%{version}.dist-info

%changelog
* Wed Mar 26 2025 Steve Kowalik <steven.kowalik@suse.com>
- Normalize metadata directory name.
* Tue Feb 11 2025 Dirk Müller <dmueller@suse.com>
- update to 0.17.1:
  * [converters] Define our own structuring hook for fontTools
    Transform to workaround bug in cattrs when using `from
    __future__ import annotations` on NamedTuple
* Sat Nov 23 2024 Dirk Müller <dmueller@suse.com>
- update to 0.17.0:
  * Added `outputImpliedClosingLine` parameter to Glyph.draw() method
* Wed Nov 20 2024 Dirk Müller <dmueller@suse.com>
- update to 0.16.1:
  * Drop support Python 3.7
  * Update testing dependencies and cattrs minimum version
* Thu Jan  4 2024 ecsos <ecsos@opensuse.org>
- Add %%{?sle15_python_module_pythons}
* Fri Dec  8 2023 Dirk Müller <dmueller@suse.com>
- update to 0.16.0:
  * Added `tempLib` property to Font, Layer and Glyph (like
    defcon's)
  * raise appropriate error when extras not installed
  * Bring guideline invariants up to spec
  * Made lazily loaded ufoLib2.Font objects pickleable by
    automatically un-lazifying them in custom `__getstate__`
    method (e0f3d6af).
  * Added optional support for de/serializing all ufoLib2 objects
    from/to JSON or MessagePack.
  * This uses ``cattrs`` custom converters to
    unstructure/structure ufoLib2 objects to/from basic
    serializable data structures.
  * See docstring in ``ufoLib2.serde::serde`` or #230 for
    examples.
* Tue Oct 11 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 0.13.1
  * Hotfix release to support cattrs v1.10.0 and set it as the minimum required version. It changed the name of a "omit if default"
    parameter that is relevant for our converters.
* Thu Dec 16 2021 Ben Greiner <code@bnavigator.de>
- Update to v0.12.1
  * Require Python 3.7+ by @madig in #178
  * Removed legacy Font(path), use Font.open(path) instead by
    @anthrotype in #176
- Release 0.11.4
  * Fix Font's explicit data and images kwarg converters.
- Release 0.11.3
  * Ensure data and image stores are unlazified for direct
    comparisons (#165).
- Release 0.11.2
  * Internal change: Don't compare private Font attributes,
    cleaning up pytest assert displays (#160).
  * Internal change: Do not require wheel for all setuptools
    operations (#158).
- No setup.py: Build system now uses PEP517
* Mon Feb 22 2021 Ben Greiner <code@bnavigator.de>
- update to v0.11.1
  * Component.move: apply delta to offset directly rather than
  translating, which fixes moving of flipped components.
  * Typing: add GlyphSet protocol. More elegant than referring to
  Layer and Glyph explicitly, which nicely avoids circular
  imports.
  * Some small typing fixes to circumvent microsoft/pyright#1297.
  * Add APIs Font.object_lib(obj) and Glyph.object_lib(obj) to
  explicitly handle the new public.objectLibs mechanism of
  attaching libs to anchors, guidelines, contours, components and
  points.
- Reinstate python36 build. FontTools does not need scipy anymore.
* Sat Feb 13 2021 Dirk Müller <dmueller@suse.com>
- skip python 3.6 build (no FontTools as it needs scipy)
* Thu Jul 23 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.8.0
  * Added bounds and controlPointBounds properties to Layer and Font objects, like in defcon API.
* Wed May 20 2020 Antonio Larrosa <alarrosa@suse.com>
- Initial release of python-ufoLib2
